<div align="center">
  <img src="media/logo.png" alt="Rhoa Logo" width="960" style="margin-bottom: -30px;"/>

  [![Development Status](https://img.shields.io/badge/status-pre--alpha-red)](https://github.com/nainajnahO/Rhoa)
  [![PyPI version](https://img.shields.io/pypi/v/rhoa)](https://pypi.org/project/rhoa/)
  [![Documentation](https://img.shields.io/badge/docs-available-brightgreen)](https://nainajnaho.github.io/Rhoa/)
  [![License](https://img.shields.io/pypi/l/rhoa)](https://github.com/nainajnahO/Rhoa/blob/main/LICENSE)
  [![Python versions](https://img.shields.io/pypi/pyversions/rhoa)](okhttps://pypi.org/project/rhoa/)

  **Rhoa is a Python package providing functions and pandas DataFrame extension accessors for technical analysis.**
</div>

## License

This project is licensed under the GNU General Public License v3.0 - see the [LICENSE](LICENSE) file for details.

## Installation

```bash
pip install rhoa
```
